import{g as l,I as f,R as o}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="482a16ee-abff-4cd2-b9eb-08e98eec308e",e._sentryDebugIdIdentifier="sentry-dbid-482a16ee-abff-4cd2-b9eb-08e98eec308e")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){u(e,a,n[a])})}return e}function u(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var c=function(t,n){var r=i({},t,n.attrs);return l(f,i({},r,{icon:o}),null)};c.displayName="ExclamationCircleOutlined";c.inheritAttrs=!1;export{c as E};
//# sourceMappingURL=ExclamationCircleOutlined-BoIpZd7Q.js.map
