import{d as a,l as d,m as s,aG as t,q as r,n as l,ap as f}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="6ba0f748-7ebd-4a70-9d05-e5e508580929",n._sentryDebugIdIdentifier="sentry-dbid-6ba0f748-7ebd-4a70-9d05-e5e508580929")}catch{}})();const i=a({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(n){return(e,o)=>(s(),d("div",{class:t(["content-layout",{"no-padding":e.noPadding}])},[r("div",{class:t(["centered-layout",{"full-width":e.fullWidth}])},[l(e.$slots,"default",{},void 0,!0)],2)],2))}}),p=f(i,[["__scopeId","data-v-fb4d67f9"]]);export{p as C};
//# sourceMappingURL=ContentLayout-SexkWDKT.js.map
