import{_ as w}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-VbWqKJaf.js";import{A as k}from"./constants-B1LrRAnj.js";import{d as b,e as y,l as v,g as n,B as _,p as f,G as t,D as e,Y as A,aF as m,H as I,$ as a,V as i,q as B,aI as T,S as x,T as C,m as l,aJ as s,ap as D}from"./jwt-decode.esm-Dca5fHH5.js";import{u as N}from"./workspaceStore-XJ3gN0Xg.js";import{C as S}from"./index-mvr8okoq.js";import"./Logo-DAfI0pPB.js";import"./userStore-C7NmNY8K.js";import"./url-CoyBb3Dp.js";import"./colorHelpers-DW8ZpCiU.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new R().stack;c&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[c]="fa312d40-25c8-4347-9bd7-c61d5ac6f8e5",o._sentryDebugIdIdentifier="sentry-dbid-fa312d40-25c8-4347-9bd7-c61d5ac6f8e5")}catch{}})();const E={class:"inner-content"},V={class:"card-content"},H=b({__name:"Error",setup(o){const c=x(),p=C(),u=N(),g=y(()=>u.state.workspace?.name??u.state.workspace?.brandName),r=y(()=>{const{status:d}=c.params;switch(d){case"404":return{status:d,title:s.translate("i18n_page_not_found"),message:s.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:d,title:s.translate("i18n_access_denied"),message:s.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:s.translate("i18n_internal_error"),message:s.translate("i18n_internal_error_message"),showAd:!1}}}),h=()=>{p.push({name:"playerHome"})};return(d,G)=>(l(),v("div",E,[n(e(A),null,{default:t(()=>[a(i(r.value.title),1)]),_:1}),n(e(m),{class:"message"},{default:t(()=>[a(i(r.value.message),1)]),_:1}),r.value.action?(l(),_(e(I),{key:0,type:"link",onClick:h},{default:t(()=>[a(i(r.value.action),1)]),_:1})):f("",!0),r.value.showAd?(l(),_(e(S),{key:1,bordered:!1,class:"card"},{default:t(()=>[B("div",V,[n(w,{style:{"margin-bottom":"10px"}}),n(e(m),null,{default:t(()=>[a("This page is part of "+i(g.value?`the ${g.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(u).state.workspace?(l(),_(e(m),{key:0},{default:t(()=>[a("Automate your own processes by getting started "),n(e(T),{href:e(k).HOMEPAGE},{default:t(()=>[a("here")]),_:1},8,["href"]),a(".")]),_:1})):f("",!0)])]),_:1})):f("",!0)]))}}),R=D(H,[["__scopeId","data-v-522ad0d4"]]);export{R as default};
//# sourceMappingURL=Error-C6HVJzB1.js.map
