import{_ as o}from"./App.vue_vue_type_style_index_0_lang-BdpBbSnQ.js";import"./userStore-C7NmNY8K.js";import"./jwt-decode.esm-Dca5fHH5.js";import"./PlayerConfigProvider-COveBbiz.js";import"./colorHelpers-DW8ZpCiU.js";import"./workspaceStore-XJ3gN0Xg.js";import"./url-CoyBb3Dp.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="ba8240c7-45dc-4133-88fa-cdde036a05fc",e._sentryDebugIdIdentifier="sentry-dbid-ba8240c7-45dc-4133-88fa-cdde036a05fc")}catch{}})();export{o as default};
//# sourceMappingURL=App-UEc2-LIB.js.map
