import{O as d}from"./index-DjAbyHeM.js";import{d as l,X as i,l as u,g as t,G as o,D as n,Y as c,Z as f,$ as s,m as _}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a70f31e1-c991-4381-a654-a08e26020d7a",e._sentryDebugIdIdentifier="sentry-dbid-a70f31e1-c991-4381-a654-a08e26020d7a")}catch{}})();const p=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new d().logoutCallback()}),(a,r)=>(_(),u("div",null,[t(n(c),null,{default:o(()=>[s("You're authenticated")]),_:1}),t(n(f),null,{default:o(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLogoutCallback-DTSU4jzq.js.map
