import{ap as c,l as o,n as s,q as n,p as a,m as d}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="2de9b825-f7d2-4bce-a7c2-3c87be83b180",e._sentryDebugIdIdentifier="sentry-dbid-2de9b825-f7d2-4bce-a7c2-3c87be83b180")}catch{}})();const r={},i={class:"base-layout"},f={class:"base-middle"},l={class:"content"},u={class:"left"},b={key:0,class:"base-footer"},_={key:0};function y(e,t){return d(),o("div",i,[s(e.$slots,"sidebar",{},void 0,!0),n("section",f,[s(e.$slots,"navbar",{},void 0,!0),n("section",l,[n("section",u,[s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(d(),o("section",b,[s(e.$slots,"footer",{},void 0,!0)])):a("",!0)]),e.$slots.chat?(d(),o("section",_,[s(e.$slots,"chat",{},void 0,!0)])):a("",!0)])])])}const m=c(r,[["render",y],["__scopeId","data-v-fe23e6dd"]]);export{m as B};
//# sourceMappingURL=BaseLayout-CAFdFQyK.js.map
