import{i as k}from"./metadata-CdAmAdig.js";import{W as h}from"./Watermark-C95DBwfe.js";import{F as w}from"./PhArrowSquareOut.vue-ztkY6P_e.js";import{d as b,e as v,r as x,l as m,p as C,D as e,g as c,G as s,M as u,B as r,$ as y,aF as g,F as D,U as F,T as I,m as t,aG as z,aH as T,V as B,ap as V}from"./jwt-decode.esm-Dca5fHH5.js";import{u as H}from"./workspaceStore-XJ3gN0Xg.js";import{C as L}from"./index-mvr8okoq.js";import{L as N}from"./LoadingOutlined-DDGxAZbf.js";import"./PhWebhooksLogo.vue-JOavTArk.js";import"./index-DjAbyHeM.js";import"./constants-B1LrRAnj.js";import"./userStore-C7NmNY8K.js";import"./url-CoyBb3Dp.js";import"./colorHelpers-DW8ZpCiU.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[n]="6d1aadfc-da8f-4aba-9d46-ff62dcf3310e",o._sentryDebugIdIdentifier="sentry-dbid-6d1aadfc-da8f-4aba-9d46-ff62dcf3310e")}catch{}})();const S={key:0,class:"home-container"},W=b({__name:"Home",setup(o){const n=I(),i=H(),p=v(()=>i.state.workspace?.sidebar.filter(d=>d.id!=="home")||[]),l=x(null),_=async(d,f)=>{l.value=f,await n.push({path:`/${d}`}),l.value=null};return(d,f)=>e(i).state.workspace?(t(),m("div",S,[c(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:s(()=>[p.value.length===0?(t(),r(e(g),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:s(()=>[y(" There are no forms available for you. ")]),_:1})):(t(!0),m(D,{key:1},F(p.value,a=>(t(),r(e(L),{key:a.id,class:z(["form-card",{loading:l.value===a.id}]),"body-style":{cursor:"pointer"},onClick:$=>_(a.path,a.id)},{default:s(()=>[c(e(u),{gap:"large",align:"center",justify:"space-between"},{default:s(()=>[(t(),r(T(e(k)(a.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),c(e(g),{style:{"font-size":"18px","font-weight":"500"}},{default:s(()=>[y(B(a.name),1)]),_:2},1024),l.value!==a.id?(t(),r(e(w),{key:0,size:"20"})):(t(),r(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),c(h,{class:"watermark","page-id":"home",locale:e(i).state.workspace.language},null,8,["locale"])])):C("",!0)}}),X=V(W,[["__scopeId","data-v-060376d1"]]);export{X as default};
//# sourceMappingURL=Home-D9ebzDGX.js.map
