import{A as a}from"./index-BFZHdHfr.js";import{d as o,e as r,l as f,p,aG as l,g as d,D as i,m as c,ap as u}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="4f2f5e03-236a-4312-8f45-4e3af414d741",e._sentryDebugIdIdentifier="sentry-dbid-4f2f5e03-236a-4312-8f45-4e3af414d741")}catch{}})();const m=o({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,y)=>t.stepsInfo?(c(),f("nav",{key:0,class:l(["p-steps",{"full-screen":!t.isPreview}])},[d(i(a),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):p("",!0)}}),b=u(m,[["__scopeId","data-v-8b0ea4f1"]]);export{b as S};
//# sourceMappingURL=Steps-C6PdqcTg.js.map
