import{P as g}from"./PlayerNavbar-Cae7TVia.js";import{d as _,S as c,r as h,e as y,l as k,B as b,p as v,q as w,D as n,g as L,W as C,T as I,m as i,ap as N}from"./jwt-decode.esm-Dca5fHH5.js";import{u as B}from"./workspaceStore-XJ3gN0Xg.js";import"./userStore-C7NmNY8K.js";import"./index-DjAbyHeM.js";import"./metadata-CdAmAdig.js";import"./PhWebhooksLogo.vue-JOavTArk.js";import"./LoadingOutlined-DDGxAZbf.js";import"./PhSignOut.vue-XpGBgo63.js";import"./index-BLK1I0IS.js";import"./url-CoyBb3Dp.js";import"./colorHelpers-DW8ZpCiU.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="4fc74716-d03b-4acd-ad5d-1565496c4910",o._sentryDebugIdIdentifier="sentry-dbid-4fc74716-d03b-4acd-ad5d-1565496c4910")}catch{}})();const D={class:"main-container"},V={class:"content"},R=_({__name:"Main",setup(o){const e=I(),t=B(),d=c().path,a=h(null),u=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=y(()=>!!c().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return i(),k("div",D,[n(t).state.workspace?(i(),b(g,{key:0,"current-path":n(d),"hide-login":m.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",V,[L(f)])])}}}),F=N(R,[["__scopeId","data-v-f095bece"]]);export{F as default};
//# sourceMappingURL=Main-CX8JXHyK.js.map
