import{O as d}from"./index-DjAbyHeM.js";import{d as l,X as i,l as u,g as a,G as n,D as o,Y as c,Z as f,$ as s,m as _}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="828ff837-9909-4485-9d5e-0898070e5775",e._sentryDebugIdIdentifier="sentry-dbid-828ff837-9909-4485-9d5e-0898070e5775")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new d().loginCallback()}),(t,r)=>(_(),u("div",null,[a(o(c),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(f),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback-DLNLbnhk.js.map
