import{d as i,e as r,l as o,p as d,aG as c,V as p,aU as f,m as t,ap as u}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="798da327-d51c-4b32-8eb1-f91f88ab135d",e._sentryDebugIdIdentifier="sentry-dbid-798da327-d51c-4b32-8eb1-f91f88ab135d")}catch{}})();const g={class:"logo"},m=["src","alt"],b=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;f(a=>({"4521d904":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),l=r(()=>`${s.brandName} Logo`);return(a,_)=>(t(),o("div",g,[a.imageUrl?(t(),o("img",{key:0,class:"logo-img",src:a.imageUrl,alt:l.value},null,8,m)):d("",!0),a.hideText?d("",!0):(t(),o("span",{key:1,class:c(a.size)},p(a.brandName),3))]))}}),h=u(b,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo-DAfI0pPB.js.map
