import{d as V,b as L,P as O,u as M,a as W,c as q,e as o,r as F,w as H,f as J,g as p,_ as f,F as K,h as G,t as j,i as Q,C as h}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="faaebd84-c1e0-4849-a462-51863b419676",e._sentryDebugIdIdentifier="sentry-dbid-faaebd84-c1e0-4849-a462-51863b419676")}catch{}})();const U={small:8,middle:16,large:24},X=()=>({prefixCls:String,size:{type:[String,Number,Array]},direction:O.oneOf(j("horizontal","vertical")).def("horizontal"),align:O.oneOf(j("start","end","center","baseline")),wrap:L()});function Y(e){return typeof e=="string"?U[e]:e||0}const m=V({compatConfig:{MODE:3},name:"ASpace",inheritAttrs:!1,props:X(),slots:Object,setup(e,r){let{slots:l,attrs:g}=r;const{prefixCls:n,space:y,direction:w}=M("space",e),[B,E]=W(n),x=q(),s=o(()=>{var t,a,i;return(i=(t=e.size)!==null&&t!==void 0?t:(a=y?.value)===null||a===void 0?void 0:a.size)!==null&&i!==void 0?i:"small"}),b=F(),c=F();H(s,()=>{[b.value,c.value]=(Array.isArray(s.value)?s.value:[s.value,s.value]).map(t=>Y(t))},{immediate:!0});const z=o(()=>e.align===void 0&&e.direction==="horizontal"?"center":e.align),P=o(()=>Q(n.value,E.value,`${n.value}-${e.direction}`,{[`${n.value}-rtl`]:w.value==="rtl",[`${n.value}-align-${z.value}`]:z.value})),k=o(()=>w.value==="rtl"?"marginLeft":"marginRight"),R=o(()=>{const t={};return x.value&&(t.columnGap=`${b.value}px`,t.rowGap=`${c.value}px`),f(f({},t),e.wrap&&{flexWrap:"wrap",marginBottom:`${-c.value}px`})});return()=>{var t,a;const{wrap:i,direction:T="horizontal"}=e,_=(t=l.default)===null||t===void 0?void 0:t.call(l),C=J(_),I=C.length;if(I===0)return null;const u=(a=l.split)===null||a===void 0?void 0:a.call(l),A=`${n.value}-item`,D=b.value,S=I-1;return p("div",G(G({},g),{},{class:[P.value,g.class],style:[R.value,g.style]}),[C.map((N,d)=>{let $=_.indexOf(N);$===-1&&($=`$$space-${d}`);let v={};return x.value||(T==="vertical"?d<S&&(v={marginBottom:`${D/(u?2:1)}px`}):v=f(f({},d<S&&{[k.value]:`${D/(u?2:1)}px`}),i&&{paddingBottom:`${c.value}px`})),B(p(K,{key:$},[p("div",{class:A,style:v},[N]),d<S&&u&&p("span",{class:`${A}-split`,style:v},[u])]))})])}}});m.Compact=h;m.install=function(e){return e.component(m.name,m),e.component(h.name,h),e};export{m as S};
//# sourceMappingURL=index-ZQBk4l6i.js.map
