import"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="39492f0a-65b0-4c56-9332-88ed2d64c476",e._sentryDebugIdIdentifier="sentry-dbid-39492f0a-65b0-4c56-9332-88ed2d64c476")}catch{}})();const l=1e3,s=e=>{let n=null;return{startPolling:()=>{const t=async()=>{try{!document.hidden&&!e.keepPollingOnOutOfFocus&&await e.task()}finally{n=setTimeout(t,e.interval??l)}};t()},endPolling:()=>{n&&clearTimeout(n)}}};export{s as u};
//# sourceMappingURL=polling-CKeyL76l.js.map
