import{d as s,l as d,m as o,g as a,D as r,aP as c,ap as f}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="8f563230-c47d-438b-938f-be0fc07c016d",e._sentryDebugIdIdentifier="sentry-dbid-8f563230-c47d-438b-938f-be0fc07c016d")}catch{}})();const i={class:"centered"},_=s({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),d("div",i,[a(r(c))]))}}),u=f(_,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer-CAp61bup.js.map
