import{u as s}from"./userStore-C7NmNY8K.js";import{W as n}from"./PlayerConfigProvider-COveBbiz.js";import{u as c}from"./workspaceStore-XJ3gN0Xg.js";import{d as f,w as i,B as d,p,D as o,G as m,g as u,W as l,m as w}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="2a63fc3a-85e8-410c-9806-f7582ebdd8ca",t._sentryDebugIdIdentifier="sentry-dbid-2a63fc3a-85e8-410c-9806-f7582ebdd8ca")}catch{}})();const C=f({__name:"App",setup(t){const a=s(),e=c();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(_,y)=>{const r=l("RouterView");return o(e).state.workspace?(w(),d(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:m(()=>[u(r,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):p("",!0)}}});export{C as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang-BdpBbSnQ.js.map
