import{y as s,A as c,_ as f}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="9472f11d-74c8-4e35-bdaf-1a31fffdb95d",e._sentryDebugIdIdentifier="sentry-dbid-9472f11d-74c8-4e35-bdaf-1a31fffdb95d")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:i,TimePicker:m,QuarterPicker:o,RangePicker:a}=s(c),g=f(n,{WeekPicker:t,MonthPicker:r,YearPicker:i,RangePicker:a,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(a.name,a),e.component(r.name,r),e.component(t.name,t),e.component(o.name,o),e)});export{g as D,r as M,o as Q,a as R,t as W};
//# sourceMappingURL=dayjs-C3kKJZJG.js.map
