import{d as b,T as f,S as m,B as p,m as l,G as c,l as g,F as _,U as y,g as v,D as n,q as T,V as k}from"./jwt-decode.esm-Dca5fHH5.js";import{A as w,T as D}from"./index-mvr8okoq.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="00e217a0-bc2d-49f3-a9ec-4862a6f62134",e._sentryDebugIdIdentifier="sentry-dbid-00e217a0-bc2d-49f3-a9ec-4862a6f62134")}catch{}})();const h=b({__name:"TablesTabs",setup(e){const a=f(),t=m(),u=String(t.name),d=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],i=o=>{a.push({name:String(o),params:{projectId:d}})};return(o,I)=>(l(),p(n(D),{"active-key":n(u),options:r,"onUpdate:activeKey":i},{default:c(()=>[(l(),g(_,null,y(r,s=>v(n(w),{key:s.value,name:s.value},{tab:c(()=>[T("span",null,k(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{h as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-BOH5jv3X.js.map
