import"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="fc50d103-fae0-4e4f-85b0-09dfaf7cc75a",e._sentryDebugIdIdentifier="sentry-dbid-fc50d103-fae0-4e4f-85b0-09dfaf7cc75a")}catch{}})();const f=e=>{try{return new URL(e),!0}catch{return!1}},d=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),n=new URLSearchParams(t.search);return Object.entries(r).forEach(([a,s])=>{t.searchParams.delete(a),n.set(a,s)}),`${t.origin}${t.pathname}?${n.toString()}`};export{f as i,d as m};
//# sourceMappingURL=url-CoyBb3Dp.js.map
