import"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="b9022193-1d4f-47cb-9b4d-14cb9378cfd4",e._sentryDebugIdIdentifier="sentry-dbid-b9022193-1d4f-47cb-9b4d-14cb9378cfd4")}catch{}})();const b=(...e)=>window.fetch(...e);export{b as l};
//# sourceMappingURL=fetch-CmLIxYFV.js.map
