import{d as c,e as b,B as d,m as r,D as n,E as g,G as a,g as l,H as i,J as p,K as m,M as u,n as y,p as f,s as B}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="e8e3d665-5b08-4048-914d-622496d3db93",t._sentryDebugIdIdentifier="sentry-dbid-e8e3d665-5b08-4048-914d-622496d3db93")}catch{}})();const h=c({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(t){const e=t,s=b(()=>e.disabledTooltip&&e.disabled?e.disabledTooltip:e.tooltip);return(o,_)=>s.value?(r(),d(n(g),{key:0,title:s.value},{default:a(()=>[l(n(i),p(m(o.$props)),{default:a(()=>[l(n(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[o.loading?f("",!0):y(o.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(r(),d(n(i),p(B({key:1},o.$props)),{default:a(()=>[l(n(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[o.loading?f("",!0):y(o.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{h as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang-D-iosY4j.js.map
