import{O as a}from"./OmniChat-BeJb0i6D.js";import{u as s}from"./omniChatStore-Bi-5MYwj.js";import{d as i,S as c,B as d,p as l,D as t,m as p}from"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="5aaea54d-8690-4e12-850f-0a7a30f3bb32",e._sentryDebugIdIdentifier="sentry-dbid-5aaea54d-8690-4e12-850f-0a7a30f3bb32")}catch{}})();const b=i({__name:"ConsoleOmniChat",setup(e){const n=c().params.projectId,o=s();return o.init("console",n),(f,u)=>t(o).controller&&t(o).repository?(p(),d(a,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)}},null,8,["ai-chat-repository","controller","environment"])):l("",!0)}});export{b as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang-CYF3gVSU.js.map
