import{as as r,at as n,au as o,av as d,aw as p,ax as c,ay as f,az as m,aA as u,aB as s,aC as g,aD as y,aE as l}from"./jwt-decode.esm-Dca5fHH5.js";import{g as w,r as i}from"./workspaceStore-XJ3gN0Xg.js";import{s as b}from"./index-DjAbyHeM.js";import{_}from"./App.vue_vue_type_style_index_0_lang-BdpBbSnQ.js";import"./userStore-C7NmNY8K.js";import"./url-CoyBb3Dp.js";import"./colorHelpers-DW8ZpCiU.js";import"./PlayerConfigProvider-COveBbiz.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="af9a6d02-7c13-4df2-96a7-187ef5dc30e4",a._sentryDebugIdIdentifier="sentry-dbid-af9a6d02-7c13-4df2-96a7-187ef5dc30e4")}catch{}})();class I{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await b();const a=await w(),t=r(),e=n({render:()=>o(_)});d.init(),p(e,i,a),I.init(),e.use(i),e.use(t),e.use(c),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",m),e.component("Message",u),s(e,g),s(e,y),s(e,l)})();
//# sourceMappingURL=player-BVi7a0wG.js.map
