import{_ as c}from"./Login.vue_vue_type_script_setup_true_lang-BC_tHwoy.js";import{d as p,l as i,g as u,D as n,T as m,S as l,m as f,ap as _}from"./jwt-decode.esm-Dca5fHH5.js";import{u as g}from"./workspaceStore-XJ3gN0Xg.js";import"./index-DjAbyHeM.js";import"./CircularLoading-ohVkmYRk.js";import"./Logo-DAfI0pPB.js";import"./string-BYR4BIXr.js";import"./index-BKOa5q_P.js";import"./userStore-C7NmNY8K.js";import"./url-CoyBb3Dp.js";import"./colorHelpers-DW8ZpCiU.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="dd0d3905-9a8d-4358-aee0-ab084fe683fe",e._sentryDebugIdIdentifier="sentry-dbid-dd0d3905-9a8d-4358-aee0-ab084fe683fe")}catch{}})();const b={class:"runner"},y=p({__name:"Login",setup(e){const o=m(),r=l(),a=g(),d=async()=>{const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(f(),i("div",b,[u(c,{"logo-url":n(a).state.workspace?.logoUrl??void 0,"brand-name":n(a).state.workspace?.brandName,locale:n(a).state.workspace?.language??"en",onDone:d},null,8,["logo-url","brand-name","locale"])]))}}),L=_(y,[["__scopeId","data-v-cb33c596"]]);export{L as default};
//# sourceMappingURL=Login-swYlbgxx.js.map
