import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-VbWqKJaf.js";import{B as y}from"./BaseLayout-CAFdFQyK.js";import{d as l,aK as _,bu as g,ap as u,ah as v,ai as h,m as f,l as b,q as o,a$ as s,X as w,T as S,B,G as n,S as $,g as i,D as k}from"./jwt-decode.esm-Dca5fHH5.js";import{u as I}from"./editor-BaKilXnS.js";import{a as D}from"./index-CXHcOjiL.js";import"./Logo-DAfI0pPB.js";import"./workspaceStore-XJ3gN0Xg.js";import"./userStore-C7NmNY8K.js";import"./url-CoyBb3Dp.js";import"./colorHelpers-DW8ZpCiU.js";import"./index-DjAbyHeM.js";import"./linters-DMK5Dyyj.js";import"./asyncComputed-IJY6wgme.js";import"./constants-B1LrRAnj.js";import"./index-Cyx2lZTa.js";import"./index-BLK1I0IS.js";import"./index-ZQBk4l6i.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="04413805-174f-4839-8224-407ac60ea5a9",e._sentryDebugIdIdentifier="sentry-dbid-04413805-174f-4839-8224-407ac60ea5a9")}catch{}})();const L=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const a=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...g(a)}}}),x={class:"v-spinner"};function K(e,a,r,d,c,p){return v((f(),b("div",x,[o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[h,e.loading]])}const P=u(L,[["render",K],["__scopeId","data-v-06538001"]]),R={class:"content"},z=l({__name:"ProjectLogin",setup(e){const a=$(),r=S(),d=I();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),r.replace(t.pathname+t.search)}function p(){const t=a.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){r.push({name:"error"});return}await d.createLogin(t).then(c),r.push({name:"editor"})}),(t,C)=>(f(),B(y,null,{navbar:n(()=>[i(k(D),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[o("div",R,[i(P)])]),_:1}))}}),Y=u(z,[["__scopeId","data-v-d2a19803"]]);export{Y as default};
//# sourceMappingURL=ProjectLogin-D-9RagYX.js.map
