import{C as t}from"./router-D5wfdag3.js";import"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="3658ed07-a562-4e3f-b22d-f608117c5f37",r._sentryDebugIdIdentifier="sentry-dbid-3658ed07-a562-4e3f-b22d-f608117c5f37")}catch{}})();class s{async list(e){return t.get(`organizations/${e}/folders`)}async create(e){return t.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,n){return t.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return t.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{s as F};
//# sourceMappingURL=folder-CMrXs2lc.js.map
