import{C as n,_ as p}from"./View.vue_vue_type_script_setup_true_lang-P5tmmb4u.js";import{d as i,S as s,B as m,m as a,D as c}from"./jwt-decode.esm-Dca5fHH5.js";import"./router-D5wfdag3.js";import"./index-Cyx2lZTa.js";import"./fetch-CmLIxYFV.js";import"./record-BZIfMWML.js";import"./SaveButton-O5UjZDE_.js";import"./ExclamationCircleOutlined-BoIpZd7Q.js";import"./CrudView-wZnp03a2.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-BnwqPwfA.js";import"./constants-B1LrRAnj.js";import"./url-CoyBb3Dp.js";import"./PhDotsThreeVertical.vue-B1x6I4wD.js";import"./index-ZQBk4l6i.js";import"./asyncComputed-IJY6wgme.js";import"./polling-CKeyL76l.js";import"./omniChatStore-Bi-5MYwj.js";import"./uuid-CK8Ke_G7.js";import"./PhCopySimple.vue-C9uB_c9T.js";import"./PhPencil.vue-DCNvh_hA.js";import"./index-BKOa5q_P.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d754f930-32e8-497c-94fa-45e482f18dcc",o._sentryDebugIdIdentifier="sentry-dbid-d754f930-32e8-497c-94fa-45e482f18dcc")}catch{}})();const q=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new n(e);return(d,f)=>(a(),m(p,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{q as default};
//# sourceMappingURL=EnvVars-xF4DCOOD.js.map
