import"./jwt-decode.esm-Dca5fHH5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},w=new Error().stack;w&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[w]="573dce77-5ef1-4786-aaea-c993974be3aa",e._sentryDebugIdIdentifier="sentry-dbid-573dce77-5ef1-4786-aaea-c993974be3aa")}catch{}})();var I={},S={},M;function R(){return M||(M=1,Object.defineProperty(S,"__esModule",{value:!0}),S.regionAPIs=void 0,S.regionAPIs=new Map([["us","https://api-iam.intercom.io"],["eu","https://api-iam.eu.intercom.io"],["ap","https://api-iam.au.intercom.io"]])),S}var d={},k;function V(){if(k)return d;k=1;var e=d&&d.__awaiter||function(o,a,s,i){function f(l){return l instanceof s?l:new s(function(v){v(l)})}return new(s||(s=Promise))(function(l,v){function p(r){try{y(i.next(r))}catch(_){v(_)}}function C(r){try{y(i.throw(r))}catch(_){v(_)}}function y(r){r.done?l(r.value):f(r.value).then(p,C)}y((i=i.apply(o,a||[])).next())})};Object.defineProperty(d,"__esModule",{value:!0}),d.ref=d.init=void 0;const w="_intercom_npm_loader",u=function(){u.loaderQueue(arguments)};u.q=[],u.loaderQueue=function(o){u.q.push(o)};const h=function(){var o,a,s=document;if(!s.getElementById(w)){var i=s.createElement("script");i.type="text/javascript",i.async=!0,i.id=w,i.src="https://widget.intercom.io/widget/"+((o=window.intercomSettings)===null||o===void 0?void 0:o.app_id);var f=s.getElementsByTagName("script")[0];(a=f.parentNode)===null||a===void 0||a.insertBefore(i,f)}},t=()=>document.readyState==="complete"||document.readyState==="interactive",E=()=>e(void 0,void 0,void 0,function*(){var o=window,a=o.Intercom;o.intercomSettings&&(o.intercomSettings.installation_type="npm-package"),typeof a=="function"?(a("reattach_activator"),a("update",o.intercomSettings)):(o.Intercom=u,t()?h():(document.addEventListener("readystatechange",function(){t()&&h()}),o.attachEvent?o.attachEvent("onload",h):o.addEventListener("load",h,!1)))});return d.init=E,d.ref=void 0,d}var O;function B(){return O||(O=1,function(e){var w=I&&I.__rest||function(n,g){var b={};for(var c in n)Object.prototype.hasOwnProperty.call(n,c)&&g.indexOf(c)<0&&(b[c]=n[c]);if(n!=null&&typeof Object.getOwnPropertySymbols=="function")for(var m=0,c=Object.getOwnPropertySymbols(n);m<c.length;m++)g.indexOf(c[m])<0&&Object.prototype.propertyIsEnumerable.call(n,c[m])&&(b[c[m]]=n[c[m]]);return b};Object.defineProperty(e,"__esModule",{value:!0}),e.onUserEmailSupplied=e.showConversation=e.showTicket=e.startChecklist=e.startSurvey=e.showNews=e.showArticle=e.startTour=e.getVisitorId=e.trackEvent=e.onUnreadCountChange=e.onShow=e.onHide=e.showNewMessage=e.showMessages=e.showSpace=e.show=e.hide=e.update=e.shutdown=e.boot=e.Intercom=void 0;const u=R(),h=V(),t=(n,...g)=>{typeof window!==void 0&&window.Intercom?window.Intercom(n,...g):console.warn("Please ensure Intercom is setup and running on client-side!")},E=n=>{if(typeof n!="object"){console.warn("Intercom initialiser called with invalid parameters.");return}const{region:g="us"}=n,b=w(n,["region"]);typeof window<"u"&&!h.ref&&(window.intercomSettings=Object.assign(Object.assign({},b),{api_base:u.regionAPIs.get(g)}),(0,h.init)())};e.Intercom=E,e.default=e.Intercom;const o=n=>t("boot",n);e.boot=o;const a=()=>t("shutdown");e.shutdown=a;const s=n=>t("update",n);e.update=s;const i=()=>t("hide");e.hide=i;const f=()=>t("show");e.show=f;const l=n=>t("showSpace",n);e.showSpace=l;const v=()=>t("showMessages");e.showMessages=v;const p=n=>t("showNewMessage",n);e.showNewMessage=p;const C=n=>t("onHide",n);e.onHide=C;const y=n=>t("onShow",n);e.onShow=y;const r=n=>t("onUnreadCountChange",n);e.onUnreadCountChange=r;const _=(...n)=>t("trackEvent",...n);e.trackEvent=_;const j=()=>t("getVisitorId");e.getVisitorId=j;const N=n=>t("startTour",n);e.startTour=N;const T=n=>t("showArticle",n);e.showArticle=T;const q=n=>t("showNews",n);e.showNews=q;const P=n=>t("startSurvey",n);e.startSurvey=P;const U=n=>t("startChecklist",n);e.startChecklist=U;const A=n=>t("showTicket",n);e.showTicket=A;const D=n=>t("showConversation",n);e.showConversation=D;const H=n=>t("onUserEmailSupplied",n);e.onUserEmailSupplied=H}(I)),I}var Q=B();export{Q as d};
//# sourceMappingURL=index-Cyx2lZTa.js.map
